@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | Xdebug                                                               |
    +----------------------------------------------------------------------+
-   | Copyright (c) 2002-2018 Derick Rethans <derick@xdebug.org>           |
+   | Copyright (c) 2002-2021 Derick Rethans <derick@xdebug.org>           |
    |           (c) 1997-2004 Jim Winstead <jimw@trainedmonkey.com>        |
    |           (c) 1998-2004 Andi Gutmans <andi@zend.com> and             |
    |                         Zeev Suraski <zeev@zend.com>                 |
@@ -357,17 +357,6 @@ zend_ulong xdebug_get_pid(void)
 #endif
 }
 
-zend_class_entry *xdebug_fetch_class(char *classname, int classname_len, int flags)
-{
-	zend_class_entry *tmp_ce;
-	zend_string *classname_str = zend_string_init(classname, classname_len, 0);
-
-	tmp_ce = zend_fetch_class(classname_str, flags);
-	zend_string_release(classname_str);
-
-	return tmp_ce;
-}
-
 void xdebug_setcookie(const char *name, int name_len, char *value, int value_len, time_t expires, const char *path, int path_len, const char *domain, int domain_len, int secure, int url_encode, int httponly)
 {
 	zend_string *name_s   = name ? zend_string_init(name, name_len, 0) : NULL;
@@ -375,7 +364,9 @@ void xdebug_setcookie(const char *name, int name_len, char *value, int value_len
 	zend_string *path_s   = path ? zend_string_init(path, path_len, 0) : NULL;
 	zend_string *domain_s = domain ? zend_string_init(domain, domain_len, 0) : NULL;
 #if PHP_VERSION_ID >= 70300
-	php_setcookie(name_s, value_s, expires, path_s, domain_s, secure, httponly, NULL, url_encode);
+	zend_string *samesite_s = zend_string_init("Lax", sizeof("Lax") - 1, 0);
+	php_setcookie(name_s, value_s, expires, path_s, domain_s, secure, httponly, samesite_s, url_encode);
+	zend_string_release(samesite_s);
 #else
 	php_setcookie(name_s, value_s, expires, path_s, domain_s, secure, url_encode, httponly);
 #endif
